==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/SummaryCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { SummaryCellInfoDescription } from "./SummaryCellInfoDescription";
/**
 * @hidden
 */
export let SummaryCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class SummaryCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (SummaryCellInfoDescriptionMetadata.a == null) {
                SummaryCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SummaryCellInfoDescriptionMetadata.c(SummaryCellInfoDescriptionMetadata.a);
            }
            if (a.j(SummaryCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.y(SummaryCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            CellInfoDescriptionMetadata.c(a);
            a.item("ResolvedSummaryLabel", "String");
            a.item("ResolvedSummaryValue", "String");
            a.item("SummaryLabelTextColor", "Brush");
            a.item("SummaryLabelFontFamily", "(w:SummaryLabelFontFamily/FontFamilyTransform,xam:SummaryLabelFontFamily,wf:SummaryLabelFontFamily,web:font/FontFamilyTransform)String");
            a.item("SummaryLabelFontSize", "(w:SummaryLabelFontSize,xam:SummaryLabelFontSize,wf:SummaryLabelFontSize,web:font/FontSizeTransform)Number:double");
            a.item("SummaryLabelFontStyle", "(w:SummaryLabelFontStyle/FontStyleTransform,xam:SummaryLabelFontFamily/FontStyleTransform,wf:SummaryLabelFontFamily/FontStyleTransform,web:font/FontStyleTransform)String");
            a.item("SummaryLabelFontWeight", "(w:SummaryLabelFontWeight/FontWeightTransform,xam:SummaryLabelFontFamily/FontWeightTransform,wf:SummaryLabelFontFamily/FontWeightTransform,web:font/FontWeightTransform)String");
        }
        static d(a) {
            SummaryCellInfoDescriptionMetadata.b(a);
            a.aa("SummaryCellInfo", () => new SummaryCellInfoDescription());
            a.z("SummaryCellInfo", SummaryCellInfoDescriptionMetadata.a);
        }
    }
    SummaryCellInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(SummaryCellInfoDescriptionMetadata, 'SummaryCellInfoDescriptionMetadata');
    SummaryCellInfoDescriptionMetadata.a = null;
    return SummaryCellInfoDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/SummaryCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { SummaryCellInfoDescription } from "./SummaryCellInfoDescription";
/**
 * @hidden
 */
export let SummaryCellInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class SummaryCellInfoDescriptionMetadata extends Base {
        static b(a) {
            if (SummaryCellInfoDescriptionMetadata.a == null) {
                SummaryCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SummaryCellInfoDescriptionMetadata.c(SummaryCellInfoDescriptionMetadata.a);
            }
            if (a.k(SummaryCellInfoDescriptionMetadata.a)) {
                return;
            }
            a.aa(SummaryCellInfoDescriptionMetadata.a);
        }
        static c(a) {
            CellInfoDescriptionMetadata.c(a);
            a.item("ResolvedSummaryLabel", "String");
            a.item("ResolvedSummaryValue", "String");
            a.item("SummaryLabelTextColor", "Brush");
            a.item("SummaryLabelFontFamily", "(w:SummaryLabelFontFamily/FontFamilyTransform,xam:SummaryLabelFontFamily,wf:SummaryLabelFontFamily,web:font/FontFamilyTransform)String");
            a.item("SummaryLabelFontSize", "(w:SummaryLabelFontSize,xam:SummaryLabelFontSize,wf:SummaryLabelFontSize,web:font/FontSizeTransform)Number:double");
            a.item("SummaryLabelFontStyle", "(w:SummaryLabelFontStyle/FontStyleTransform,xam:SummaryLabelFontFamily/FontStyleTransform,wf:SummaryLabelFontFamily/FontStyleTransform,web:font/FontStyleTransform)String");
            a.item("SummaryLabelFontWeight", "(w:SummaryLabelFontWeight/FontWeightTransform,xam:SummaryLabelFontFamily/FontWeightTransform,wf:SummaryLabelFontFamily/FontWeightTransform,web:font/FontWeightTransform)String");
        }
        static d(a) {
            SummaryCellInfoDescriptionMetadata.b(a);
            a.ac("SummaryCellInfo", () => new SummaryCellInfoDescription());
            a.ab("SummaryCellInfo", SummaryCellInfoDescriptionMetadata.a);
        }
    }
    SummaryCellInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(SummaryCellInfoDescriptionMetadata, 'SummaryCellInfoDescriptionMetadata');
    SummaryCellInfoDescriptionMetadata.a = null;
    return SummaryCellInfoDescriptionMetadata;
})();
